Exception: KQueue::Event::UnexpectedEvent

Inherits:
Exception
  • Object
show all
Defined in:
lib/rb-kqueue/event.rb

Overview

Exception raised on an attempt to construct an KQueue::Event from a native event with unexpected field values.